#include "mainwindow.h"
#include "ui_mainwindow.h"
#include <QStringList>
#include <QList>
#include <QColor>
#include <QMessageBox>
#include "ratingdelegate.h"

MainWindow::MainWindow(QWidget *parent) :
    QMainWindow(parent),
    ui(new Ui::MainWindow)
{
    ui->setupUi(this);
    model = new QStandardItemModel(this);
    QStringList headerRow;
    headerRow.append("Composer");
    headerRow.append("Album title");
    headerRow.append("Replacement cost");
    headerRow.append("Rating");
    model->setHorizontalHeaderLabels(headerRow);
    ui->tableView->setModel(model);

    // QTableView view set up in GUI
    ui->tableView->setSortingEnabled(true);
    ui->tableView->horizontalHeader()->setStretchLastSection(true);
    ui->tableView->setItemDelegateForColumn(3, new RatingDelegate(this));

    connect(ui->addButton, SIGNAL(clicked()), this, SLOT(addItem()));
    connect(ui->deleteButton, SIGNAL(clicked()), this, SLOT(deleteRow()));
    connect(model, SIGNAL(itemChanged(QStandardItem*)), this, SLOT(updateRow(QStandardItem*)));
}

void MainWindow::addItem()
{
    // get values
    QString composer = ui->composer->text();
    QString album = ui->album->text();
    float price = ui->price->value();
    int rating = ui->rating->value();

    // reset GUI
    ui->composer->clear();
    ui->album->clear();
    ui->price->setValue(0.0);
    ui->rating->setValue(0);
    ui->composer->setFocus();

    // add to model
    QList<QStandardItem*> row;
    QStandardItem *composerItem = new QStandardItem(composer);
    QStandardItem *albumItem = new QStandardItem(album);
    QStandardItem *priceItem = new QStandardItem();
    priceItem->setData(QString::number(price, 'f', 2), Qt::DisplayRole);
    QStandardItem *ratingItem = new QStandardItem();
    ratingItem->setData(QString::number(rating), Qt::DisplayRole);
    row << composerItem << albumItem << priceItem << ratingItem;
    model->appendRow(row);
    updateRow(priceItem);  // to set colours
}

void MainWindow::updateRow(QStandardItem *item)
{
    QColor colour = Qt::white;
    int row = item->row();
    if (model->item(row, 2)->data(Qt::DisplayRole).toFloat() >= 200)
        colour = Qt::red;
    for (int col=0; col<4; col++)
        model->item(row, col)->setBackground(colour);
}

void MainWindow::deleteRow()
{
    QModelIndex index = ui->tableView->currentIndex();
    if (!index.isValid())
        return;
    if (QMessageBox::Yes == QMessageBox::warning(this, "Delete row", "Are you sure?", QMessageBox::Yes | QMessageBox::No))
    {
        int row = index.row();
        model->removeRow(row);
    }
}

MainWindow::~MainWindow()
{
    delete ui;
}
