#include "mainwindow.h"
#include "ui_mainwindow.h"
#include <QFileDialog>
#include <QFile>
#include <QMessageBox>
#include <QString>
#include <QTextStream>
#include <QTextCursor>

QRegExp MainWindow::email("[\\w\\.]+@[\\w\\.]+");
QRegExp MainWindow::tel1("\\d{3,3}\\-{0,1}\\d{3,3}\\-{0,1}\\d{4,4}");
QRegExp MainWindow::tel2("\\(\\d{3,3}\\)\\d{3,3}\\-{0,1}\\d{4,4}");

MainWindow::MainWindow(QWidget *parent) :
    QMainWindow(parent),
    ui(new Ui::MainWindow)
{
    ui->setupUi(this);
    ui->processButton->setEnabled(false);
    document = new QTextDocument(this);

    connect (ui->loadButton, SIGNAL(clicked()), this, SLOT(load()));
    connect(ui->processButton, SIGNAL(clicked()), this, SLOT(processContents()));
}

void MainWindow::load()
{
    ui->displayText->clear();
    QString fileName = QFileDialog::getOpenFileName(this, "Open file", ".", "Text files (*.txt)");
    QFile file(fileName);
    if (!file.open(QIODevice::ReadOnly))
    {
        QMessageBox::critical(this, "File error", "Could not open file " + fileName, QMessageBox::Ok);
        return;
    }
    QTextStream in(&file);
    while (!in.atEnd())
    {
        QString line = in.readLine();
        ui->displayText->append(line);
    }
    ui->processButton->setEnabled(true);
    file.close();
}

void MainWindow::processContents()
{
    document = ui->displayText->document();
    QTextCharFormat format;
    format.setFontWeight(80);

    QList<QRegExp> regexs;
    regexs << email <<tel1 << tel2;

    foreach(QRegExp regex, regexs)
    {
        QTextCursor cursor(document);
        while (!cursor.isNull() && !cursor.atEnd())
        {
            cursor = document->find(regex, cursor);

            if (!cursor.isNull())
            {
                cursor.movePosition(QTextCursor::WordRight, QTextCursor::KeepAnchor, tel1.matchedLength());
                cursor.mergeCharFormat(format);
            }
        }
    }
    QMessageBox::information(this, "Done", "Checking completed");
}

MainWindow::~MainWindow()
{
    delete ui;
}
