#include <QHeaderView>
#include <QHBoxLayout>
#include <QVBoxLayout>
#include <QInputDialog>
#include <QMessageBox>
#include <QFileSystemWatcher>

#include "directoryviewer.h"

DirectoryViewer::DirectoryViewer(){
    model = new QFileSystemModel;
    model->setReadOnly(false);
    model->setRootPath("");

    treeView = new QTreeView;
    treeView->setModel(model);    
    treeView->header()->setClickable(true);

    QModelIndex index = model->index(QDir::currentPath());
    treeView->expand(index);
    treeView->scrollTo(index);
    treeView->resizeColumnToContents(0);

    mkdirButton = new QPushButton("New Folder");
    removeButton = new QPushButton("Remove");
    upButton = new QPushButton("Up");

    QHBoxLayout *buttonLayout = new QHBoxLayout;
    buttonLayout->addWidget(mkdirButton);
    buttonLayout->addWidget(removeButton);
    buttonLayout->addWidget(upButton);
    buttonLayout->addStretch();

    QVBoxLayout *mainLayout = new QVBoxLayout;
    mainLayout->addWidget(treeView);
    mainLayout->addLayout(buttonLayout);
    setLayout(mainLayout);

    connect(mkdirButton, SIGNAL(clicked()),this, SLOT(createDirectory()));
    connect(removeButton, SIGNAL(clicked()), this, SLOT(remove()));
    connect(upButton, SIGNAL(clicked()), this, SLOT(up()));

    setWindowTitle("Directory Viewer");
}

void DirectoryViewer::createDirectory(){
    QModelIndex index = treeView->currentIndex();
    if (!index.isValid())
        return;

    QString dirName = QInputDialog::getText(this,"Create Directory", "Directory name");
    if (!dirName.isEmpty()) {
        if (!model->mkdir(index, dirName).isValid())
            QMessageBox::information(this, "Create Directory", "Failed to create the directory");
    }
}

void DirectoryViewer::remove(){
    QModelIndex index = treeView->currentIndex();    
    if (!index.isValid())
        return;

    bool ok;
    if (model->fileInfo(index).isDir()) {        
        ok = model->rmdir(index);
    } else {
        ok = model->remove(index);
    }
    if (!ok)
        QMessageBox::information(this, "Remove", QString("Failed to remove %1").arg(model->fileName(index)));
}

void DirectoryViewer::up(){
  QModelIndex index = treeView->currentIndex();
  QModelIndex parent = index.parent();
  treeView->setCurrentIndex(parent);
}
